from filelog import Writer
def calfib(loop, log):
    n = 1
    x = 0
    p = x
    if log == True:
        for i in range(loop):
            x = n
            n = (n + p)
            Writer('current', False) >> n
            p = x
            Writer('previos', False) >> p
    else:
        for i in range(loop):
            x = n
            n = (n + p)
            p = x
    return n

def calfiblon(log):
    n = 1
    x = 0
    p = x
    if log == True:
        while True:
            x = n
            n = (n + p)
            Writer('current', False) >> n
            p = x
            Writer('previos', False) >> p
    if log == False:
        while True:
            x = n
            n = (n + p)
            p = x



from setuptools import setup
from pathlib import Path
this_directory = Path(__file__).parent

__project__  = "Ranthon"
__version__ = "1.1.5"
__description__ = "A collection of Python packages written by Walter J Hare."
__packages__ = ["infseq"]
__install_requires__ = ["filelog", "math", "decimal" "random"]
__long_description__ = (this_directory / "README.md").read_text()
__long_description_content_type__ = 'text/markdown'
__url__ = 'https://github.com/WFlyToTheSky/RanthonRepo'
__license_files__ = ('LICENSE.txt')

setup(
    name = __project__,
    version = __version__,
    description = __description__,
    packages = __packages__,
    install_requires = __install_requires__,
    long_description = __long_description__,
    long_description_content_type = __long_description_content_type__,
    url = __url__,
    license_files = __license_files__
)



import math
from decimal import *
from filelog import Writer
import random

def calpidart(seed, rounds, log):
    inside = 0
    random.seed(seed)

    if log == True:
        for i in range(rounds):
            # compute position of the point
            x = random.uniform(0.0, 1.0)
            y = random.uniform(0.0, 1.0)
            result = x*x + y*y
            if (result <= 1.0):
                inside += 1
            Writer('current', False) >> inside

    else:
        for i in range(rounds):
            # compute position of the point
            x = random.uniform(0.0, 1.0)
            y = random.uniform(0.0, 1.0)
            result = x*x + y*y
            if (result <= 1.0):
                inside += 1

    return(inside)

def calpidartlon(seed, log):
    inside = 0
    random.seed(seed)

    if log == True:
        while True:
            # compute position of the point
            x = random.uniform(0.0, 1.0)
            y = random.uniform(0.0, 1.0)
            result = x*x + y*y
            if (result <= 1.0):
                inside += 1
            Writer('current', False) >> inside

    else:
        while True:
            # compute position of the point
            x = random.uniform(0.0, 1.0)
            y = random.uniform(0.0, 1.0)
            result = x*x + y*y
            if (result <= 1.0):
                inside += 1

def calpivie(rounds, digetmax, log):
    purple = Decimal(math.sqrt(2))
    answer = Decimal(purple / 2)
    getcontext().prec = digetmax

    if log == True:
        for i in range(rounds):
            purple = Decimal(math.sqrt(2 + purple))
            answer = Decimal(answer * (purple / 2))
            Writer('current', False) >> Decimal(2 / answer)
    else:
        for i in range(rounds):
            purple = Decimal(math.sqrt(2 + purple))
            answer = Decimal(answer * (purple / 2))
                      
    return(Decimal(2 / answer))

def calpivielon(digetmax, log):
    purple = Decimal(math.sqrt(2))
    answer = Decimal(purple / 2)
    getcontext().prec = digetmax

    if log == True:
        while True:
            purple = Decimal(math.sqrt(2 + purple))
            answer = Decimal(answer * (purple / 2))
            Writer('current', False) >> Decimal(2 / answer)
    else:
        while True:
            purple = Decimal(math.sqrt(2 + purple))
            answer = Decimal(answer * (purple / 2))
